@@ -34,9 +34,6 @@ from rich.prompt import Confirm
 from utils import open_file, run_process, executable_exists, console, logger
 import importlib.metadata
 
-
-
-
 __author__ = "Abdeladim S."
 __github__ = ""
 __copyright__ = "Copyright 2022"
@@ -108,8 +105,9 @@ class Latex2pdfa:
         :param qpdf: qpdf executable
         """
         self.script_name = __file__  # the name of the script
-        self.resources = (Path('.').parent / 'resources').absolute()
-        self.binaries = (Path('.').parent / 'binaries').absolute()
+        d = os.path.dirname(sys.modules[self.script_name].__file__)
+        self.resources = (d / 'resources').absolute()
+        self.binaries = (d / 'binaries').absolute()
 
         self.main_tex_file = Path(main_tex_file)
         assert conformance_level in ['a', 'b', 'u']
